==> bigloo2.0a.tar.gz: bigloo2.0a/recette/0cfa.scm <==
;*---------------------------------------------------------------------*/
;*   A pratical implementation for the Scheme programming language     */
;*                                                                     */
;*                                    ,--^,                            */
;*                              _ ___/ /|/                             */
;*                          ,;'( )__, ) '                              */
;*                         ;;  //   L__.                               */
;*                         '   \\   /  '                               */
;*                              ^   ^                                  */
;*                                                                     */
;*   Copyright (c) 1992-1999 Manuel Serrano                            */
;*                                                                     */
;*     Bug descriptions, use reports, comments or suggestions are      */
;*     welcome. Send them to                                           */
;*       bigloo-request@kaolin.unice.fr                                */
;*       http://kaolin.unice.fr/bigloo                                 */
;*                                                                     */
;*   This program is free software; you can redistribute it            */
;*   and/or modify it under the terms of the GNU General Public        */
;*   License as published by the Free Software Foundation; either      */
;*   version 2 of the License, or (at your option) any later version.  */
;*                                                                     */
;*   This program is distributed in the hope that it will be useful,   */
;*   but WITHOUT ANY WARRANTY; without even the implied warranty of    */
;*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     */
;*   GNU General Public License for more details.                      */
;*                                                                     */
;*   You should have received a copy of the GNU General Public         */
;*   License along with this program; if not, write to the Free        */
;*   Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,   */
;*   MA 02111-1307, USA.                                               */
;*---------------------------------------------------------------------*/
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/recette/0cfa.scm                     */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Jul  7 11:13:48 1993                          */
;*    Last change :  Sun Jun 28 16:04:08 1998 (serrano)                */
;*                                                                     */
;*    Quelques tests sur la 0cfa                                       */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module 0cfa
   (import  (main "main.scm")
	    (module "module.scm")
	    (cfa2 "cfa2.scm"))
   (include "test.sch")
   (export  (test-0cfa)
	    sc-vm))

(define-macro (O4)
   (set! *optim* 4)
   (set! *unsafe-type* #t)
   (set! *unsafe-range* #t)
   '#unspecified)

(O4)

;*---------------------------------------------------------------------*/
;*    Un test qui ne se compilait pas                                  */
;*---------------------------------------------------------------------*/
(define (foo x)
   (begin 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 1 2 3 4 5 6 7 8 9
	  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 1 2 3 4 5 6 7 8 9)
   (labels ((bar () gee)
            (gee (y) (+fx y 1)))
      ((bar) 5)))

(foo 1)

;*---------------------------------------------------------------------*/
;*    set-car ...                                                      */
;*---------------------------------------------------------------------*/
(define (set-car)
   (let ((l (cons 1 2)))
      (let ((y (car l)))
	 (set-car! l '())
	 (integer? (car l)))))

;*---------------------------------------------------------------------*/
;*    extra-light ...                                                  */
;*---------------------------------------------------------------------*/
(define (foo-of-extra-light f)
   (begin 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 1 2 3 4 5 6 7 8 9
	  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 1 2 3 4 5 6 7 8 9)
   (f))

(define (extra-light x)
   (labels ((f1 () x)
	    (f2 () (f1)))
      (foo-of-extra-light f2)))

;*---------------------------------------------------------------------*/
;*    Va args in -O4 mode ...                                          */
;*---------------------------------------------------------------------*/
(define va-args
    (lambda (name . default)
       ((lambda (scan)
           (begin
	      (set! scan
		    (lambda (i)
		       (let ((class i))
			  (if (pair? default)
			      (let ((fun (car default)))
				 (fun name))))))
	      (scan 1)))
	(unspecified))))


(define (va-args-main)
   (let ((gee (lambda (name) (begin #t))))
      (va-args 0 gee)))

;*---------------------------------------------------------------------*/
;*    parse ...                                                        */
;*---------------------------------------------------------------------*/
(define (parse iport)
   (let ((body1017 (lambda () (let ((lalr::procedure fun))
				 (let ((v (lalr 4)))
				    v))))
	 (result1019 '()))
      (set! result1019 (body1017))))

;*---------------------------------------------------------------------*/
;*    X-bug ...                                                        */
;*---------------------------------------------------------------------*/
(define (X-bug x)
   (let ((f (lambda (y) x)))
      (cfa2 f)))

;*---------------------------------------------------------------------*/
;*    Another compiler error                                           */
;*---------------------------------------------------------------------*/
(define my-fetch-byte
   (lambda (max-pc prgm)
      0 1 2 3 4 5 6 7 8 9
      0 1 2 3 4 5 6 7 8 9
      0 1 2 3 4 5 6 7 8 9
      (if (=fx max-pc 0)
          #f
          (let ((bug (vector-ref prgm 0)))
             bug))))

(define (sc-vm . action)
   (+fx 1 (my-fetch-byte 0 (cdr action))))

;*---------------------------------------------------------------------*/
;*    test-0cfa ...                                                    */
;*---------------------------------------------------------------------*/
(define (test-0cfa)
   (test-module "0cfa" "0cfa.scm")
   (test "set-car!" (set-car) #f)
   (test "extra-light" (extra-light 1) 1)
   (test "va-args" (va-args-main) #t)
   (test "funcall" (parse #t) #unspecified)
   (test "X" (X-bug 4) 4))

==> bigloo2.6b.tar.gz: bigloo2.6b/recette/0cfa.scm <==
;*=====================================================================*/
;*    serrano/prgm/project/bigloo/recette/0cfa.scm                     */
;*                                                                     */
;*    Author      :  Manuel Serrano                                    */
;*    Creation    :  Wed Jul  7 11:13:48 1993                          */
;*    Last change :  Sat Jan 13 08:37:42 2001 (serrano)                */
;*                                                                     */
;*    Quelques tests sur la 0cfa                                       */
;*=====================================================================*/

;*---------------------------------------------------------------------*/
;*    Le module                                                        */
;*---------------------------------------------------------------------*/
(module 0cfa
   (import  (main "main.scm")
	    (module "module.scm")
	    (cfa2 "cfa2.scm"))
   (include "test.sch")
   (export  (test-0cfa)
	    sc-vm))

(define-macro (O4)
   (set! *optim* 4)
   (set! *unsafe-type* #t)
   (set! *unsafe-range* #t)
   '#unspecified)

(O4)

;*---------------------------------------------------------------------*/
;*    Un test qui ne se compilait pas                                  */
;*---------------------------------------------------------------------*/
(define (foo x)
   (begin 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 1 2 3 4 5 6 7 8 9
	  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 1 2 3 4 5 6 7 8 9)
   (labels ((bar () gee)
            (gee (y) (+fx y 1)))
      ((bar) 5)))

(foo 1)

;*---------------------------------------------------------------------*/
;*    set-car ...                                                      */
;*---------------------------------------------------------------------*/
(define (set-car)
   (let ((l (cons 1 2)))
      (let ((y (car l)))
	 (set-car! l '())
	 (integer? (car l)))))

;*---------------------------------------------------------------------*/
;*    extra-light ...                                                  */
;*---------------------------------------------------------------------*/
(define (foo-of-extra-light f)
   (begin 0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 1 2 3 4 5 6 7 8 9
	  0 1 2 3 4 5 6 7 8 9 0 1 2 3 4 5 6 7 8 9 1 2 3 4 5 6 7 8 9)
   (f))

(define (extra-light x)
   (labels ((f1 () x)
	    (f2 () (f1)))
      (foo-of-extra-light f2)))

;*---------------------------------------------------------------------*/
;*    Va args in -O4 mode ...                                          */
;*---------------------------------------------------------------------*/
(define va-args
    (lambda (name . default)
       ((lambda (scan)
           (begin
	      (set! scan
		    (lambda (i)
		       (let ((class i))
			  (if (pair? default)
			      (let ((fun (car default)))
				 (fun name))))))
	      (scan 1)))
	(unspecified))))


(define (va-args-main)
   (let ((gee (lambda (name) (begin #t))))
      (va-args 0 gee)))

;*---------------------------------------------------------------------*/
;*    parse ...                                                        */
;*---------------------------------------------------------------------*/
(define (parse iport)
   (let ((body1017 (lambda () (let ((lalr::procedure fun))
				 (let ((v (lalr 4)))
				    v))))
	 (result1019 '()))
      (set! result1019 (body1017))))

;*---------------------------------------------------------------------*/
;*    X-bug ...                                                        */
;*---------------------------------------------------------------------*/
(define (X-bug x)
   (let ((f (lambda (y) x)))
      (cfa2 f)))

;*---------------------------------------------------------------------*/
;*    Another compiler error                                           */
;*---------------------------------------------------------------------*/
(define my-fetch-byte
   (lambda (max-pc prgm)
      0 1 2 3 4 5 6 7 8 9
      0 1 2 3 4 5 6 7 8 9
      0 1 2 3 4 5 6 7 8 9
      (if (=fx max-pc 0)
          #f
          (let ((bug (vector-ref prgm 0)))
             bug))))

(define (sc-vm . action)
   (+fx 1 (my-fetch-byte 0 (cdr action))))

;*---------------------------------------------------------------------*/
;*    test-l-procedure ...                                             */
;*---------------------------------------------------------------------*/
(define (test-l-procedure argv)
   (let ((l (list "juste" "to" 'be 'sure 'that "there" 'is 'no
		  'inlining 'in 'this 'function)))
      (let ((f (bar argv)))
	 (f 3 4 5))))


(define (bar argv)
   (cond
      ((null? (cdr argv))
       (lambda (a b c) (cons argv 1)))
      ((null? (cddr argv))
       (lambda (a b c) (cons argv 2)))
      ((null? (cdddr argv))
       (lambda (a b c) (cons argv 3)))
      (else
       (lambda (a b c) (cons argv 4)))))

;*---------------------------------------------------------------------*/
;*    test-0cfa ...                                                    */
;*---------------------------------------------------------------------*/
(define (test-0cfa)
   (test-module "0cfa" "0cfa.scm")
   (test "set-car!" (set-car) #f)
   (test "extra-light" (extra-light 1) 1)
   (test "va-args" (va-args-main) #t)
   (test "funcall" (parse #t) #unspecified)
   (test "X" (X-bug 4) 4)
   (let ((l '(1)))
      (test "light" (test-l-procedure l) (cons l 1)))
   (let ((l '(1 2)))
      (test "light" (test-l-procedure l) (cons l 2))))
